@@ -1,22 +1,50 @@
+import base64
+
 from yoti_python_sdk.utils import YotiSerializable
 from yoti_python_sandbox.doc_scan.document_filter import (  # noqa: F401
     SandboxDocumentFilter,
 )
 
 
-class SandboxDocumentTextDataExtractionTaskResult(YotiSerializable):
-    def __init__(self, document_fields=None):
-        if document_fields is None:
-            document_fields = dict()
+class SandboxDocumentIdPhoto(YotiSerializable):
+    def __init__(self, content_type, data):
+        """
+        :param str content_type: the content type
+        :param bytes data: the image data
+        """
+        self.__content_type = content_type
+        self.__data = data
 
+    def to_json(self):
+        return {
+            "content_type": self.__content_type,
+            "data": base64.b64encode(self.__data).decode("utf-8"),
+        }
+
+
+class SandboxDocumentTextDataExtractionTaskResult(YotiSerializable):
+    def __init__(self, document_fields=None, document_id_photo=None):
         self.__document_fields = document_fields
+        self.__document_id_photo = document_id_photo
 
     @property
     def document_fields(self):
         return self.__document_fields
 
+    @property
+    def document_id_photo(self):
+        return self.__document_id_photo
+
     def to_json(self):
-        return {"document_fields": self.document_fields}
+        json = {}
+
+        if self.document_fields is not None:
+            json["document_fields"] = self.document_fields
+
+        if self.document_id_photo is not None:
+            json["document_id_photo"] = self.document_id_photo
+
+        return json
 
 
 class SandboxDocumentTextDataExtractionTask(YotiSerializable):
@@ -49,10 +77,17 @@ class SandboxDocumentTextDataExtractionTask(YotiSerializable):
 
 class SandboxDocumentTextDataExtractionTaskBuilder(object):
     def __init__(self):
-        self.__document_fields = dict()
+        self.__document_fields = None
         self.__document_filter = None
+        self.__document_id_photo = None
 
     def with_document_field(self, key, value):
+        """
+        :type key: str
+        :type value: str or dict
+        :rtype: SandboxDocumentTextDataExtractionTaskBuilder
+        """
+        self.__document_fields = self.__document_fields or {}
         self.__document_fields[key] = value
         return self
 
@@ -61,13 +96,27 @@ class SandboxDocumentTextDataExtractionTaskBuilder(object):
         :type document_fields: dict
         :rtype: SandboxDocumentTextDataExtractionTaskBuilder
         """
-        self.__document_fields.update(document_fields)
+        self.__document_fields = document_fields
+        return self
+
+    def with_document_id_photo(self, content_type, data):
+        """
+        :param str content_type: the content type
+        :param bytes data: the image data
+        """
+        self.__document_id_photo = SandboxDocumentIdPhoto(content_type, data)
         return self
 
     def with_document_filter(self, document_filter):
+        """
+        :type document_filter: SandboxDocumentFilter
+        :rtype: SandboxDocumentTextDataExtractionTaskBuilder
+        """
         self.__document_filter = document_filter
         return self
 
     def build(self):
-        result = SandboxDocumentTextDataExtractionTaskResult(self.__document_fields)
+        result = SandboxDocumentTextDataExtractionTaskResult(
+            self.__document_fields, self.__document_id_photo
+        )
         return SandboxDocumentTextDataExtractionTask(result, self.__document_filter)
